@@ -7,7 +7,7 @@ import (
 	"math/big"
 	"testing"
 
-	"github.com/consensys/gnark-crypto/ecc/bls24-317/fp"
+	"github.com/consensys/gnark-crypto/ecc/bls24-315/fp"
 	"github.com/leanovate/gopter"
 	"github.com/leanovate/gopter/prop"
 )
@@ -24,7 +24,7 @@ func TestE24Serialization(t *testing.T) {
 
 	genA := GenE24()
 
-	properties.Property("[BLS24-317] SetBytes(Bytes()) should stay constant", prop.ForAll(
+	properties.Property("[BLS24-315] SetBytes(Bytes()) should stay constant", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			buf := a.Bytes()
@@ -49,7 +49,7 @@ func TestE24ReceiverIsOperand(t *testing.T) {
 	genA := GenE24()
 	genB := GenE24()
 
-	properties.Property("[BLS24-317] Having the receiver as operand (addition) should output the same result", prop.ForAll(
+	properties.Property("[BLS24-315] Having the receiver as operand (addition) should output the same result", prop.ForAll(
 		func(a, b *E24) bool {
 			var c, d E24
 			d.Set(a)
@@ -62,7 +62,7 @@ func TestE24ReceiverIsOperand(t *testing.T) {
 		genB,
 	))
 
-	properties.Property("[BLS24-317] Having the receiver as operand (sub) should output the same result", prop.ForAll(
+	properties.Property("[BLS24-315] Having the receiver as operand (sub) should output the same result", prop.ForAll(
 		func(a, b *E24) bool {
 			var c, d E24
 			d.Set(a)
@@ -75,7 +75,7 @@ func TestE24ReceiverIsOperand(t *testing.T) {
 		genB,
 	))
 
-	properties.Property("[BLS24-317] Having the receiver as operand (mul) should output the same result", prop.ForAll(
+	properties.Property("[BLS24-315] Having the receiver as operand (mul) should output the same result", prop.ForAll(
 		func(a, b *E24) bool {
 			var c, d E24
 			d.Set(a)
@@ -88,7 +88,7 @@ func TestE24ReceiverIsOperand(t *testing.T) {
 		genB,
 	))
 
-	properties.Property("[BLS24-317] Having the receiver as operand (square) should output the same result", prop.ForAll(
+	properties.Property("[BLS24-315] Having the receiver as operand (square) should output the same result", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			b.Square(a)
@@ -98,7 +98,7 @@ func TestE24ReceiverIsOperand(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] Having the receiver as operand (double) should output the same result", prop.ForAll(
+	properties.Property("[BLS24-315] Having the receiver as operand (double) should output the same result", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			b.Double(a)
@@ -108,7 +108,7 @@ func TestE24ReceiverIsOperand(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] Having the receiver as operand (Inverse) should output the same result", prop.ForAll(
+	properties.Property("[BLS24-315] Having the receiver as operand (Inverse) should output the same result", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			b.Inverse(a)
@@ -118,7 +118,7 @@ func TestE24ReceiverIsOperand(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] Having the receiver as operand (Cyclotomic square) should output the same result", prop.ForAll(
+	properties.Property("[BLS24-315] Having the receiver as operand (Cyclotomic square) should output the same result", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			b.CyclotomicSquare(a)
@@ -128,7 +128,7 @@ func TestE24ReceiverIsOperand(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] Having the receiver as operand (Conjugate) should output the same result", prop.ForAll(
+	properties.Property("[BLS24-315] Having the receiver as operand (Conjugate) should output the same result", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			b.Conjugate(a)
@@ -138,7 +138,7 @@ func TestE24ReceiverIsOperand(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] Having the receiver as operand (Frobenius) should output the same result", prop.ForAll(
+	properties.Property("[BLS24-315] Having the receiver as operand (Frobenius) should output the same result", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			b.Frobenius(a)
@@ -148,7 +148,7 @@ func TestE24ReceiverIsOperand(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] Having the receiver as operand (FrobeniusSquare) should output the same result", prop.ForAll(
+	properties.Property("[BLS24-315] Having the receiver as operand (FrobeniusSquare) should output the same result", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			b.FrobeniusSquare(a)
@@ -158,7 +158,7 @@ func TestE24ReceiverIsOperand(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] Having the receiver as operand (FrobeniusQuad) should output the same result", prop.ForAll(
+	properties.Property("[BLS24-315] Having the receiver as operand (FrobeniusQuad) should output the same result", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			b.FrobeniusQuad(a)
@@ -182,7 +182,7 @@ func TestE24Ops(t *testing.T) {
 	genB := GenE24()
 	genExp := GenFp()
 
-	properties.Property("[BLS24-317] sub & add should leave an element invariant", prop.ForAll(
+	properties.Property("[BLS24-315] sub & add should leave an element invariant", prop.ForAll(
 		func(a, b *E24) bool {
 			var c E24
 			c.Set(a)
@@ -193,7 +193,7 @@ func TestE24Ops(t *testing.T) {
 		genB,
 	))
 
-	properties.Property("[BLS24-317] mul & inverse should leave an element invariant", prop.ForAll(
+	properties.Property("[BLS24-315] mul & inverse should leave an element invariant", prop.ForAll(
 		func(a, b *E24) bool {
 			var c, d E24
 			d.Inverse(b)
@@ -205,7 +205,7 @@ func TestE24Ops(t *testing.T) {
 		genB,
 	))
 
-	properties.Property("[BLS24-317] inverse twice should leave an element invariant", prop.ForAll(
+	properties.Property("[BLS24-315] inverse twice should leave an element invariant", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			b.Inverse(a).Inverse(&b)
@@ -214,7 +214,7 @@ func TestE24Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] square and mul should output the same result", prop.ForAll(
+	properties.Property("[BLS24-315] square and mul should output the same result", prop.ForAll(
 		func(a *E24) bool {
 			var b, c E24
 			b.Mul(a, a)
@@ -224,7 +224,7 @@ func TestE24Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] a + pi(a), a-pi(a) should be real", prop.ForAll(
+	properties.Property("[BLS24-315] a + pi(a), a-pi(a) should be real", prop.ForAll(
 		func(a *E24) bool {
 			var b, c, d E24
 			var e, f, g E12
@@ -273,7 +273,7 @@ func TestE24Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] pi**24=id", prop.ForAll(
+	properties.Property("[BLS24-315] pi**24=id", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			b.Frobenius(a).
@@ -305,7 +305,7 @@ func TestE24Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] (pi**2)**12=id", prop.ForAll(
+	properties.Property("[BLS24-315] (pi**2)**12=id", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			b.FrobeniusSquare(a).
@@ -326,7 +326,7 @@ func TestE24Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] (pi**4)**6=id", prop.ForAll(
+	properties.Property("[BLS24-315] (pi**4)**6=id", prop.ForAll(
 		func(a *E24) bool {
 			var b E24
 			b.FrobeniusQuad(a).
@@ -341,7 +341,7 @@ func TestE24Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] cyclotomic square (Granger-Scott) and square should be the same in the cyclotomic subgroup", prop.ForAll(
+	properties.Property("[BLS24-315] cyclotomic square (Granger-Scott) and square should be the same in the cyclotomic subgroup", prop.ForAll(
 		func(a *E24) bool {
 			var b, c, d E24
 			b.Conjugate(a)
@@ -355,7 +355,7 @@ func TestE24Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] compressed cyclotomic square (Karabina) and square should be the same in the cyclotomic subgroup", prop.ForAll(
+	properties.Property("[BLS24-315] compressed cyclotomic square (Karabina) and square should be the same in the cyclotomic subgroup", prop.ForAll(
 		func(a *E24) bool {
 			var _a, b, c, d, _c, _d E24
 			_a.SetOne().Double(&_a)
@@ -385,6 +385,40 @@ func TestE24Ops(t *testing.T) {
 		genA,
 	))
 
+	properties.Property("[BLS24-315] batch decompress and individual decompress (Karabina) should be the same", prop.ForAll(
+		func(a *E24) bool {
+			var _a, b E24
+			_a.SetOne().Double(&_a)
+
+			// put a and _a in the cyclotomic subgroup
+			// a (g3 !=0 probably)
+			b.Conjugate(a)
+			a.Inverse(a)
+			b.Mul(&b, a)
+			a.FrobeniusQuad(&b).Mul(a, &b)
+			// _a (g3 == 0)
+			b.Conjugate(&_a)
+			_a.Inverse(&_a)
+			b.Mul(&b, &_a)
+			_a.FrobeniusQuad(&b).Mul(&_a, &b)
+
+			var a2, a4, a17 E24
+			a2.Set(&_a)
+			a4.Set(a)
+			a17.Set(a)
+			a2.nSquareCompressed(2) // case g3 == 0
+			a4.nSquareCompressed(4)
+			a17.nSquareCompressed(17)
+			batch := BatchDecompressKarabina([]E24{a2, a4, a17})
+			a2.DecompressKarabina(&a2)
+			a4.DecompressKarabina(&a4)
+			a17.DecompressKarabina(&a17)
+
+			return a2.Equal(&batch[0]) && a4.Equal(&batch[1]) && a17.Equal(&batch[2])
+		},
+		genA,
+	))
+
 	properties.Property("[BLS24-315] Exp and CyclotomicExp results must be the same in the cyclotomic subgroup", prop.ForAll(
 		func(a *E24, e fp.Element) bool {
 			var b, c, d E24
@@ -408,7 +442,7 @@ func TestE24Ops(t *testing.T) {
 		genExp,
 	))
 
-	properties.Property("[BLS24-317] Frobenius of x in E24 should be equal to x^q", prop.ForAll(
+	properties.Property("[BLS24-315] Frobenius of x in E24 should be equal to x^q", prop.ForAll(
 		func(a *E24) bool {
 			var b, c E24
 			q := fp.Modulus()
@@ -420,7 +454,7 @@ func TestE24Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] FrobeniusSquare of x in E24 should be equal to x^(q^2)", prop.ForAll(
+	properties.Property("[BLS24-315] FrobeniusSquare of x in E24 should be equal to x^(q^2)", prop.ForAll(
 		func(a *E24) bool {
 			var b, c E24
 			q := fp.Modulus()
@@ -431,7 +465,7 @@ func TestE24Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] FrobeniusQuad of x in E24 should be equal to x^(q^4)", prop.ForAll(
+	properties.Property("[BLS24-315] FrobeniusQuad of x in E24 should be equal to x^(q^4)", prop.ForAll(
 		func(a *E24) bool {
 			var b, c E24
 			q := fp.Modulus()
@@ -442,20 +476,6 @@ func TestE24Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BLS24-317] MulBy014 and Mul by (c0, c1, 0, 0, c4, 0) should output the same result", prop.ForAll(
-		func(a, b *E24) bool {
-			var c E24
-			b.D0.C2.SetZero()
-			b.D1.C0.SetZero()
-			b.D1.C2.SetZero()
-			c.Mul(a, b)
-			a.MulBy014(&b.D0.C0, &b.D0.C1, &b.D1.C1)
-			return c.Equal(a)
-		},
-		genA,
-		genA,
-	))
-
 	properties.TestingRun(t, gopter.ConsoleReporter(false))
 
 }
@@ -465,8 +485,8 @@ func TestE24Ops(t *testing.T) {
 
 func BenchmarkE24Add(b *testing.B) {
 	var a, c E24
-	a.SetRandom()
-	c.SetRandom()
+	a.MustSetRandom()
+	c.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Add(&a, &c)
@@ -475,8 +495,8 @@ func BenchmarkE24Add(b *testing.B) {
 
 func BenchmarkE24Sub(b *testing.B) {
 	var a, c E24
-	a.SetRandom()
-	c.SetRandom()
+	a.MustSetRandom()
+	c.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Sub(&a, &c)
@@ -485,8 +505,8 @@ func BenchmarkE24Sub(b *testing.B) {
 
 func BenchmarkE24Mul(b *testing.B) {
 	var a, c E24
-	a.SetRandom()
-	c.SetRandom()
+	a.MustSetRandom()
+	c.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Mul(&a, &c)
@@ -495,7 +515,7 @@ func BenchmarkE24Mul(b *testing.B) {
 
 func BenchmarkE24Cyclosquare(b *testing.B) {
 	var a E24
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.CyclotomicSquare(&a)
@@ -504,7 +524,7 @@ func BenchmarkE24Cyclosquare(b *testing.B) {
 
 func BenchmarkE24Square(b *testing.B) {
 	var a E24
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Square(&a)
@@ -513,7 +533,7 @@ func BenchmarkE24Square(b *testing.B) {
 
 func BenchmarkE24Inverse(b *testing.B) {
 	var a E24
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Inverse(&a)
@@ -522,7 +542,7 @@ func BenchmarkE24Inverse(b *testing.B) {
 
 func BenchmarkE24Conjugate(b *testing.B) {
 	var a E24
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Conjugate(&a)
@@ -531,7 +551,7 @@ func BenchmarkE24Conjugate(b *testing.B) {
 
 func BenchmarkE24Frobenius(b *testing.B) {
 	var a E24
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Frobenius(&a)
@@ -540,7 +560,7 @@ func BenchmarkE24Frobenius(b *testing.B) {
 
 func BenchmarkE24FrobeniusSquare(b *testing.B) {
 	var a E24
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.FrobeniusSquare(&a)
@@ -549,7 +569,7 @@ func BenchmarkE24FrobeniusSquare(b *testing.B) {
 
 func BenchmarkE24FrobeniusQuad(b *testing.B) {
 	var a E24
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.FrobeniusQuad(&a)
@@ -558,7 +578,7 @@ func BenchmarkE24FrobeniusQuad(b *testing.B) {
 
 func BenchmarkE24Expt(b *testing.B) {
 	var a E24
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Expt(&a)
