@@ -6,7 +6,7 @@ package fptower
 import (
 	"math/big"
 
-	"github.com/consensys/gnark-crypto/ecc/bls24-317/fp"
+	"github.com/consensys/gnark-crypto/ecc/bls24-315/fp"
 )
 
 // E4 is a degree two finite field extension of fp2
@@ -83,14 +83,14 @@ func (z *E4) MulByElement(x *E4, y *fp.Element) *E4 {
 	return z
 }
 
-// Add sets z=x+y in E4 and returns z
+// Add set z=x+y in E4 and return z
 func (z *E4) Add(x, y *E4) *E4 {
 	z.B0.Add(&x.B0, &y.B0)
 	z.B1.Add(&x.B1, &y.B1)
 	return z
 }
 
-// Sub sets z to x-y and returns z
+// Sub sets z to x sub y and return z
 func (z *E4) Sub(x, y *E4) *E4 {
 	z.B0.Sub(&x.B0, &y.B0)
 	z.B1.Sub(&x.B1, &y.B1)
@@ -122,6 +122,15 @@ func (z *E4) SetRandom() (*E4, error) {
 	return z, nil
 }
 
+// MustSetRandom sets B0 and B1 to random values.
+// Panics if reading from crypto/rand fails.
+func (z *E4) MustSetRandom() *E4 {
+	if _, err := z.SetRandom(); err != nil {
+		panic(err)
+	}
+	return z
+}
+
 // IsZero returns true if z is zero, false otherwise
 func (z *E4) IsZero() bool {
 	return z.B0.IsZero() && z.B1.IsZero()
@@ -139,18 +148,17 @@ func (z *E4) MulByNonResidue(x *E4) *E4 {
 	return z
 }
 
-// MulByNonResidueInv mul x by (0,1)⁻¹
+// MulByNonResidueInv mul x by (0,1)^{-1}
 func (z *E4) MulByNonResidueInv(x *E4) *E4 {
 	a := x.B1
 	var uInv E2
-	uInv.A0.SetString("68196535552147955757549882954137028530972556060709796988605069651952986598616012809013078365526")
-	uInv.A1.SetString("68196535552147955757549882954137028530972556060709796988605069651952986598616012809013078365525")
+	uInv.A1.SetString("6108483493771298205388567675447533806912846525679192205394505462405828322019437284165171866703")
 	z.B1.Mul(&x.B0, &uInv)
 	z.B0 = a
 	return z
 }
 
-// Mul sets z=x*y in E4 and returns z
+// Mul set z=x*y in E4 and return z
 func (z *E4) Mul(x, y *E4) *E4 {
 	var a, b, c E2
 	a.Add(&x.B0, &x.B1)
@@ -163,7 +171,7 @@ func (z *E4) Mul(x, y *E4) *E4 {
 	return z
 }
 
-// Square sets z=x*x in E4 and returns z
+// Square set z=x*x in E4 and return z
 func (z *E4) Square(x *E4) *E4 {
 
 	//Algorithm 22 from https://eprint.iacr.org/2010/354.pdf
@@ -179,7 +187,7 @@ func (z *E4) Square(x *E4) *E4 {
 	return z
 }
 
-// Inverse sets z to the inverse of x in E4 and returns z
+// Inverse set z to the inverse of x in E4 and return z
 //
 // if x == 0, sets and returns z = x
 func (z *E4) Inverse(x *E4) *E4 {
@@ -231,7 +239,7 @@ func (z *E4) Exp(x E4, k *big.Int) *E4 {
 	return z
 }
 
-// Conjugate sets z to x conjugated and returns z
+// Conjugate set z to x conjugated and return z
 func (z *E4) Conjugate(x *E4) *E4 {
 	z.B0 = x.B0
 	z.B1.Neg(&x.B1)
@@ -302,8 +310,8 @@ func (z *E4) Sqrt(x *E4) *E4 {
 	return z
 }
 
-// BatchInvertE4 returns a new slice with every element in a inverted.
-// It uses Montgomery batch inversion trick.
+// BatchInvertE4 returns a new slice with every element inverted.
+// Uses Montgomery batch inversion trick
 //
 // if a[i] == 0, returns result[i] = a[i]
 func BatchInvertE4(a []E4) []E4 {
@@ -338,7 +346,6 @@ func BatchInvertE4(a []E4) []E4 {
 	return res
 }
 
-// Div divides an element in E4 by an element in E4
 func (z *E4) Div(x *E4, y *E4) *E4 {
 	var r E4
 	r.Inverse(y).Mul(x, &r)
