@@ -6,7 +6,7 @@ package fptower
 import (
 	"math/big"
 
-	"github.com/consensys/gnark-crypto/ecc/bls24-315/fp"
+	"github.com/consensys/gnark-crypto/ecc/bls24-317/fp"
 )
 
 // E2 is a degree two finite field extension of fp.Element
@@ -80,6 +80,15 @@ func (z *E2) SetRandom() (*E2, error) {
 	return z, nil
 }
 
+// MustSetRandom sets z to a random value.
+// It panics if reading from crypto/rand fails.
+func (z *E2) MustSetRandom() *E2 {
+	if _, err := z.SetRandom(); err != nil {
+		panic(err)
+	}
+	return z
+}
+
 // IsZero returns true if z is zero, false otherwise
 func (z *E2) IsZero() bool {
 	return z.A0.IsZero() && z.A1.IsZero()
@@ -96,7 +105,7 @@ func (z *E2) Add(x, y *E2) *E2 {
 	return z
 }
 
-// Sub two elements of E2
+// Sub subtracts two elements of E2
 func (z *E2) Sub(x, y *E2) *E2 {
 	subE2(z, x, y)
 	return z
@@ -176,46 +185,59 @@ func (z *E2) Exp(x E2, k *big.Int) *E2 {
 	return z
 }
 
+func init() {
+	q := fp.Modulus()
+	tmp := big.NewInt(3)
+	sqrtExp1.Set(q).Sub(&sqrtExp1, tmp).Rsh(&sqrtExp1, 2)
+
+	tmp.SetUint64(1)
+	sqrtExp2.Set(q).Sub(&sqrtExp2, tmp).Rsh(&sqrtExp2, 1)
+}
+
+var sqrtExp1, sqrtExp2 big.Int
+
 // Sqrt sets z to the square root of and returns z
 // The function does not test whether the square root
 // exists or not, it's up to the caller to call
 // Legendre beforehand.
-// cf https://eprint.iacr.org/2012/685.pdf (algo 10)
+// cf https://eprint.iacr.org/2012/685.pdf (algo 9)
 func (z *E2) Sqrt(x *E2) *E2 {
 
-	// precomputation
-	var b, c, d, e, f, x0 E2
-	var _b, o fp.Element
+	var a1, alpha, b, x0, minusone E2
 
-	// c must be a non square (works for p=1 mod 12 hence 1 mod 4, only bls377 has such a p currently)
-	c.A1.SetOne()
+	minusone.SetOne().Neg(&minusone)
 
-	q := fp.Modulus()
-	var exp, one big.Int
-	one.SetUint64(1)
-	exp.Set(q).Sub(&exp, &one).Rsh(&exp, 1)
-	d.Exp(c, &exp)
-	e.Mul(&d, &c).Inverse(&e)
-	f.Mul(&d, &c).Square(&f)
-
-	// computation
-	exp.Rsh(&exp, 1)
-	b.Exp(*x, &exp)
-	b.norm(&_b)
-	o.SetOne()
-	if _b.Equal(&o) {
-		x0.Square(&b).Mul(&x0, x)
-		_b.Set(&x0.A0).Sqrt(&_b)
-		z.Conjugate(&b).MulByElement(z, &_b)
+	a1.Exp(*x, &sqrtExp1)
+	alpha.Square(&a1).
+		Mul(&alpha, x)
+	x0.Mul(x, &a1)
+	if alpha.Equal(&minusone) {
+		var c fp.Element
+		c.Set(&x0.A0)
+		z.A0.Neg(&x0.A1)
+		z.A1.Set(&c)
 		return z
 	}
-	x0.Square(&b).Mul(&x0, x).Mul(&x0, &f)
-	_b.Set(&x0.A0).Sqrt(&_b)
-	z.Conjugate(&b).MulByElement(z, &_b).Mul(z, &e)
+	a1.SetOne()
+	b.Add(&a1, &alpha)
+
+	b.Exp(b, &sqrtExp2).Mul(&x0, &b)
+	z.Set(&b)
+	return z
+}
+
+// Select is conditional move.
+// If cond = 0, it sets z to caseZ and returns it. otherwise caseNz.
+func (z *E2) Select(cond int, caseZ *E2, caseNz *E2) *E2 {
+	//Might be able to save a nanosecond or two by an aggregate implementation
+
+	z.A0.Select(cond, &caseZ.A0, &caseNz.A0)
+	z.A1.Select(cond, &caseZ.A1, &caseNz.A1)
 
 	return z
 }
 
+// Div divides an element in E2 by an element in E2
 func (z *E2) Div(x *E2, y *E2) *E2 {
 	var r E2
 	r.Inverse(y).Mul(x, &r)
