@@ -260,8 +260,8 @@ func TestE4Ops(t *testing.T) {
 
 func BenchmarkE4Add(b *testing.B) {
 	var a, c E4
-	_, _ = a.SetRandom()
-	_, _ = c.SetRandom()
+	a.MustSetRandom()
+	c.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Add(&a, &c)
@@ -270,8 +270,8 @@ func BenchmarkE4Add(b *testing.B) {
 
 func BenchmarkE4Sub(b *testing.B) {
 	var a, c E4
-	_, _ = a.SetRandom()
-	_, _ = c.SetRandom()
+	a.MustSetRandom()
+	c.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Sub(&a, &c)
@@ -280,8 +280,8 @@ func BenchmarkE4Sub(b *testing.B) {
 
 func BenchmarkE4Mul(b *testing.B) {
 	var a, c E4
-	_, _ = a.SetRandom()
-	_, _ = c.SetRandom()
+	a.MustSetRandom()
+	c.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Mul(&a, &c)
@@ -290,7 +290,7 @@ func BenchmarkE4Mul(b *testing.B) {
 
 func BenchmarkE4Square(b *testing.B) {
 	var a E4
-	_, _ = a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Square(&a)
@@ -299,7 +299,7 @@ func BenchmarkE4Square(b *testing.B) {
 
 func BenchmarkE4Sqrt(b *testing.B) {
 	var a E4
-	_, _ = a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Sqrt(&a)
@@ -308,7 +308,7 @@ func BenchmarkE4Sqrt(b *testing.B) {
 
 func BenchmarkE4Inverse(b *testing.B) {
 	var a E4
-	_, _ = a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Inverse(&a)
@@ -317,7 +317,7 @@ func BenchmarkE4Inverse(b *testing.B) {
 
 func BenchmarkE4MulNonRes(b *testing.B) {
 	var a E4
-	_, _ = a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.MulByNonResidue(&a)
@@ -326,7 +326,7 @@ func BenchmarkE4MulNonRes(b *testing.B) {
 
 func BenchmarkE4MulNonResInv(b *testing.B) {
 	var a E4
-	_, _ = a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.MulByNonResidueInv(&a)
@@ -334,7 +334,7 @@ func BenchmarkE4MulNonResInv(b *testing.B) {
 }
 func BenchmarkE4Conjugate(b *testing.B) {
 	var a E4
-	_, _ = a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Conjugate(&a)
