@@ -244,8 +244,8 @@ func TestE3Ops(t *testing.T) {
 
 func BenchmarkE3Add(b *testing.B) {
 	var a, c E3
-	_, _ = a.SetRandom()
-	_, _ = c.SetRandom()
+	a.MustSetRandom()
+	c.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Add(&a, &c)
@@ -254,8 +254,8 @@ func BenchmarkE3Add(b *testing.B) {
 
 func BenchmarkE3Sub(b *testing.B) {
 	var a, c E3
-	_, _ = a.SetRandom()
-	_, _ = c.SetRandom()
+	a.MustSetRandom()
+	c.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Sub(&a, &c)
@@ -264,8 +264,8 @@ func BenchmarkE3Sub(b *testing.B) {
 
 func BenchmarkE3Mul(b *testing.B) {
 	var a, c E3
-	_, _ = a.SetRandom()
-	_, _ = c.SetRandom()
+	a.MustSetRandom()
+	c.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Mul(&a, &c)
@@ -275,8 +275,8 @@ func BenchmarkE3Mul(b *testing.B) {
 func BenchmarkE3MulByElement(b *testing.B) {
 	var a E3
 	var c fp.Element
-	_, _ = c.SetRandom()
-	_, _ = a.SetRandom()
+	c.MustSetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.MulByElement(&a, &c)
@@ -285,7 +285,7 @@ func BenchmarkE3MulByElement(b *testing.B) {
 
 func BenchmarkE3Square(b *testing.B) {
 	var a E3
-	_, _ = a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Square(&a)
@@ -294,7 +294,7 @@ func BenchmarkE3Square(b *testing.B) {
 
 func BenchmarkE3Inverse(b *testing.B) {
 	var a E3
-	_, _ = a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Inverse(&a)
@@ -303,7 +303,7 @@ func BenchmarkE3Inverse(b *testing.B) {
 
 func BenchmarkE3MulNonRes(b *testing.B) {
 	var a E3
-	_, _ = a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.MulByNonResidue(&a)
