@@ -7,7 +7,7 @@ import (
 	"math/big"
 	"testing"
 
-	"github.com/consensys/gnark-crypto/ecc/bw6-633/fp"
+	"github.com/consensys/gnark-crypto/ecc/bw6-761/fp"
 	"github.com/leanovate/gopter"
 	"github.com/leanovate/gopter/prop"
 )
@@ -24,7 +24,7 @@ func TestE6Serialization(t *testing.T) {
 
 	genA := GenE6()
 
-	properties.Property("[BW6-633] SetBytes(Bytes()) should stay constant", prop.ForAll(
+	properties.Property("[BW6-761] SetBytes(Bytes()) should stay constant", prop.ForAll(
 		func(a *E6) bool {
 			var b E6
 			buf := a.Bytes()
@@ -49,7 +49,7 @@ func TestE6ReceiverIsOperand(t *testing.T) {
 	genA := GenE6()
 	genB := GenE6()
 
-	properties.Property("[BW6-633] Having the receiver as operand (addition) should output the same result", prop.ForAll(
+	properties.Property("[BW6-761] Having the receiver as operand (addition) should output the same result", prop.ForAll(
 		func(a, b *E6) bool {
 			var c, d E6
 			d.Set(a)
@@ -62,7 +62,7 @@ func TestE6ReceiverIsOperand(t *testing.T) {
 		genB,
 	))
 
-	properties.Property("[BW6-633] Having the receiver as operand (sub) should output the same result", prop.ForAll(
+	properties.Property("[BW6-761] Having the receiver as operand (sub) should output the same result", prop.ForAll(
 		func(a, b *E6) bool {
 			var c, d E6
 			d.Set(a)
@@ -75,7 +75,7 @@ func TestE6ReceiverIsOperand(t *testing.T) {
 		genB,
 	))
 
-	properties.Property("[BW6-633] Having the receiver as operand (mul) should output the same result", prop.ForAll(
+	properties.Property("[BW6-761] Having the receiver as operand (mul) should output the same result", prop.ForAll(
 		func(a, b *E6) bool {
 			var c, d E6
 			d.Set(a)
@@ -88,7 +88,7 @@ func TestE6ReceiverIsOperand(t *testing.T) {
 		genB,
 	))
 
-	properties.Property("[BW6-633] Having the receiver as operand (square) should output the same result", prop.ForAll(
+	properties.Property("[BW6-761] Having the receiver as operand (square) should output the same result", prop.ForAll(
 		func(a *E6) bool {
 			var b E6
 			b.Square(a)
@@ -98,7 +98,7 @@ func TestE6ReceiverIsOperand(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BW6-633] Having the receiver as operand (double) should output the same result", prop.ForAll(
+	properties.Property("[BW6-761] Having the receiver as operand (double) should output the same result", prop.ForAll(
 		func(a *E6) bool {
 			var b E6
 			b.Double(a)
@@ -108,7 +108,7 @@ func TestE6ReceiverIsOperand(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BW6-633] Having the receiver as operand (Inverse) should output the same result", prop.ForAll(
+	properties.Property("[BW6-761] Having the receiver as operand (Inverse) should output the same result", prop.ForAll(
 		func(a *E6) bool {
 			var b E6
 			b.Inverse(a)
@@ -118,7 +118,7 @@ func TestE6ReceiverIsOperand(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BW6-633] Having the receiver as operand (Cyclotomic square) should output the same result", prop.ForAll(
+	properties.Property("[BW6-761] Having the receiver as operand (Cyclotomic square) should output the same result", prop.ForAll(
 		func(a *E6) bool {
 			var b E6
 			b.CyclotomicSquare(a)
@@ -128,7 +128,7 @@ func TestE6ReceiverIsOperand(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BW6-633] Having the receiver as operand (Conjugate) should output the same result", prop.ForAll(
+	properties.Property("[BW6-761] Having the receiver as operand (Conjugate) should output the same result", prop.ForAll(
 		func(a *E6) bool {
 			var b E6
 			b.Conjugate(a)
@@ -138,7 +138,7 @@ func TestE6ReceiverIsOperand(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BW6-633] Having the receiver as operand (Frobenius) should output the same result", prop.ForAll(
+	properties.Property("[BW6-761] Having the receiver as operand (Frobenius) should output the same result", prop.ForAll(
 		func(a *E6) bool {
 			var b E6
 			b.Frobenius(a)
@@ -162,7 +162,7 @@ func TestE6Ops(t *testing.T) {
 	genB := GenE6()
 	genExp := GenFp()
 
-	properties.Property("[BW6-633] sub & add should leave an element invariant", prop.ForAll(
+	properties.Property("[BW6-761] sub & add should leave an element invariant", prop.ForAll(
 		func(a, b *E6) bool {
 			var c E6
 			c.Set(a)
@@ -173,7 +173,7 @@ func TestE6Ops(t *testing.T) {
 		genB,
 	))
 
-	properties.Property("[BW6-633] mul & inverse should leave an element invariant", prop.ForAll(
+	properties.Property("[BW6-761] mul & inverse should leave an element invariant", prop.ForAll(
 		func(a, b *E6) bool {
 			var c, d E6
 			d.Inverse(b)
@@ -185,7 +185,7 @@ func TestE6Ops(t *testing.T) {
 		genB,
 	))
 
-	properties.Property("[BW6-633] inverse twice should leave an element invariant", prop.ForAll(
+	properties.Property("[BW6-761] inverse twice should leave an element invariant", prop.ForAll(
 		func(a *E6) bool {
 			var b E6
 			b.Inverse(a).Inverse(&b)
@@ -194,7 +194,7 @@ func TestE6Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BW6-633] square and mul should output the same result", prop.ForAll(
+	properties.Property("[BW6-761] square and mul should output the same result", prop.ForAll(
 		func(a *E6) bool {
 			var b, c E6
 			b.Mul(a, a)
@@ -204,7 +204,7 @@ func TestE6Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BW6-633] a + pi(a), a-pi(a) should be real", prop.ForAll(
+	properties.Property("[BW6-761] a + pi(a), a-pi(a) should be real", prop.ForAll(
 		func(a *E6) bool {
 			var b, c, d E6
 			var e, f, g E3
@@ -218,7 +218,7 @@ func TestE6Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BW6-633] Torus-based Compress/decompress E6 elements in the cyclotomic subgroup", prop.ForAll(
+	properties.Property("[BW6-761] Torus-based Compress/decompress E6 elements in the cyclotomic subgroup", prop.ForAll(
 		func(a *E6) bool {
 			var b E6
 			b.Conjugate(a)
@@ -233,7 +233,7 @@ func TestE6Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BW6-633] Torus-based batch Compress/decompress E6 elements in the cyclotomic subgroup", prop.ForAll(
+	properties.Property("[BW6-761] Torus-based batch Compress/decompress E6 elements in the cyclotomic subgroup", prop.ForAll(
 		func(a, e, f *E6) bool {
 			var b E6
 			b.Conjugate(a)
@@ -253,7 +253,7 @@ func TestE6Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BW6-633] pi**12=id", prop.ForAll(
+	properties.Property("[BW6-761] pi**12=id", prop.ForAll(
 		func(a *E6) bool {
 			var b E6
 			b.Frobenius(a).
@@ -273,7 +273,7 @@ func TestE6Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BW6-633] cyclotomic square (Granger-Scott) and square should be the same in the cyclotomic subgroup", prop.ForAll(
+	properties.Property("[BW6-761] cyclotomic square (Granger-Scott) and square should be the same in the cyclotomic subgroup", prop.ForAll(
 		func(a *E6) bool {
 			var b, c, d E6
 			b.Conjugate(a)
@@ -287,27 +287,13 @@ func TestE6Ops(t *testing.T) {
 		genA,
 	))
 
-	properties.Property("[BW6-633] compressed cyclotomic square (Karabina) and square should be the same in the cyclotomic subgroup", prop.ForAll(
+	properties.Property("[BW6-761] compressed cyclotomic square (Karabina) and square should be the same in the cyclotomic subgroup", prop.ForAll(
 		func(a *E6) bool {
-			var b, c, d E6
-			b.Conjugate(a)
-			a.Inverse(a)
-			b.Mul(&b, a)
-			a.Frobenius(&b).Mul(a, &b)
-			c.Square(a)
-			d.CyclotomicSquareCompressed(a).DecompressKarabina(&d)
-			return c.Equal(&d)
-		},
-		genA,
-	))
-
-	properties.Property("[BW6-633] batch decompress and individual decompress (Karabina) should be the same", prop.ForAll(
-		func(a *E6) bool {
-			var _a, b E6
+			var _a, b, c, d, _c, _d E6
 			_a.SetOne().Double(&_a)
 
 			// put a and _a in the cyclotomic subgroup
-			// a (g3 !=0 probably)
+			// a (g3 != 0 probably)
 			b.Conjugate(a)
 			a.Inverse(a)
 			b.Mul(&b, a)
@@ -318,24 +304,20 @@ func TestE6Ops(t *testing.T) {
 			b.Mul(&b, &_a)
 			_a.Frobenius(&b).Mul(&_a, &b)
 
-			var a2, a4, a17 E6
-			a2.Set(&_a)
-			a4.Set(a)
-			a17.Set(a)
-			a2.nSquareCompressed(2) // case g3 == 0
-			a4.nSquareCompressed(4)
-			a17.nSquareCompressed(17)
-			batch := BatchDecompressKarabina([]E6{a2, a4, a17})
-			a2.DecompressKarabina(&a2)
-			a4.DecompressKarabina(&a4)
-			a17.DecompressKarabina(&a17)
+			// case g3 != 0
+			c.Square(a)
+			d.CyclotomicSquareCompressed(a).DecompressKarabina(&d)
 
-			return a2.Equal(&batch[0]) && a4.Equal(&batch[1]) && a17.Equal(&batch[2])
+			// case g3 == 0
+			_c.Square(&_a)
+			_d.CyclotomicSquareCompressed(&_a).DecompressKarabina(&_d)
+
+			return c.Equal(&d)
 		},
 		genA,
 	))
 
-	properties.Property("[BW6-633] Exp and CyclotomicExp results must be the same in the cyclotomic subgroup", prop.ForAll(
+	properties.Property("[BW6-761] Exp and CyclotomicExp results must be the same in the cyclotomic subgroup", prop.ForAll(
 		func(a *E6, e fp.Element) bool {
 			var b, c, d E6
 			// put in the cyclo subgroup
@@ -358,7 +340,7 @@ func TestE6Ops(t *testing.T) {
 		genExp,
 	))
 
-	properties.Property("[BW6-633] Frobenius of x in E6 should be equal to x^q", prop.ForAll(
+	properties.Property("[BW6-761] Frobenius of x in E6 should be equal to x^q", prop.ForAll(
 		func(a *E6) bool {
 			var b, c E6
 			q := fp.Modulus()
@@ -378,8 +360,8 @@ func TestE6Ops(t *testing.T) {
 
 func BenchmarkE6Add(b *testing.B) {
 	var a, c E6
-	a.SetRandom()
-	c.SetRandom()
+	a.MustSetRandom()
+	c.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Add(&a, &c)
@@ -388,8 +370,8 @@ func BenchmarkE6Add(b *testing.B) {
 
 func BenchmarkE6Sub(b *testing.B) {
 	var a, c E6
-	a.SetRandom()
-	c.SetRandom()
+	a.MustSetRandom()
+	c.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Sub(&a, &c)
@@ -398,8 +380,8 @@ func BenchmarkE6Sub(b *testing.B) {
 
 func BenchmarkE6Mul(b *testing.B) {
 	var a, c E6
-	a.SetRandom()
-	c.SetRandom()
+	a.MustSetRandom()
+	c.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Mul(&a, &c)
@@ -408,7 +390,7 @@ func BenchmarkE6Mul(b *testing.B) {
 
 func BenchmarkE6Cyclosquare(b *testing.B) {
 	var a E6
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.CyclotomicSquare(&a)
@@ -417,7 +399,7 @@ func BenchmarkE6Cyclosquare(b *testing.B) {
 
 func BenchmarkE6Square(b *testing.B) {
 	var a E6
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Square(&a)
@@ -426,7 +408,7 @@ func BenchmarkE6Square(b *testing.B) {
 
 func BenchmarkE6Inverse(b *testing.B) {
 	var a E6
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Inverse(&a)
@@ -435,7 +417,7 @@ func BenchmarkE6Inverse(b *testing.B) {
 
 func BenchmarkE6Conjugate(b *testing.B) {
 	var a E6
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Conjugate(&a)
@@ -444,7 +426,7 @@ func BenchmarkE6Conjugate(b *testing.B) {
 
 func BenchmarkE6Frobenius(b *testing.B) {
 	var a E6
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
 		a.Frobenius(&a)
@@ -453,7 +435,7 @@ func BenchmarkE6Frobenius(b *testing.B) {
 
 func BenchmarkE6Expt(b *testing.B) {
 	var a, c E6
-	a.SetRandom()
+	a.MustSetRandom()
 	b.ResetTimer()
 	c.Conjugate(&a)
 	a.Inverse(&a)
